diff src/conversation.h @ 11338:17142948653e

[gaim-migrate @ 13551] Change the GAIM_CONV_IM and GAIM_CONV_CHAT enums to GAIM_CONV_TYPE_IM and GAIM_CONV_TYPE_CHAT. This touched A LOT of files. Also combined two oscar header files (one of them was small and dorky). committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 25 Aug 2005 02:33:44 +0000
parents b8c93c40ee2e
children 201617d49573
line wrap: on
line diff
--- a/src/conversation.h	Thu Aug 25 00:27:12 2005 +0000
+++ b/src/conversation.h	Thu Aug 25 02:33:44 2005 +0000
@@ -44,11 +44,11 @@
  */
 typedef enum
 {
-	GAIM_CONV_UNKNOWN = 0, /**< Unknown conversation type. */
-	GAIM_CONV_IM,          /**< Instant Message.           */
-	GAIM_CONV_CHAT,        /**< Chat room.                 */
-	GAIM_CONV_MISC,        /**< A misc. conversation.      */
-	GAIM_CONV_ANY          /**< Any type of conversation.  */
+	GAIM_CONV_TYPE_UNKNOWN = 0, /**< Unknown conversation type. */
+	GAIM_CONV_TYPE_IM,          /**< Instant Message.           */
+	GAIM_CONV_TYPE_CHAT,        /**< Chat room.                 */
+	GAIM_CONV_TYPE_MISC,        /**< A misc. conversation.      */
+	GAIM_CONV_TYPE_ANY          /**< Any type of conversation.  */
 
 } GaimConversationType;
 
@@ -666,7 +666,7 @@
 /**
  * Returns the specified conversation's IM-specific data.
  *
  * If the conversation type is not GAIM_CONV_IM, this will return @c NULL.
  *
  * @param conv The conversation.
  *
@@ -679,7 +679,7 @@
 /**
  * Returns the specified conversation's chat-specific data.
  *
  * If the conversation type is not GAIM_CONV_CHAT, this will return @c NULL.
  *
  * @param conv The conversation.
  *
@@ -666,7 +666,7 @@
  * Returns the specified conversation's IM-specific data.
  *
- * If the conversation type is not GAIM_CONV_IM, this will return @c NULL.
+ * If the conversation type is not GAIM_CONV_TYPE_IM, this will return @c NULL.
  *
  * @param conv The conversation.
@@ -679,7 +679,7 @@
  * Returns the specified conversation's chat-specific data.
  *
- * If the conversation type is not GAIM_CONV_CHAT, this will return @c NULL.
+ * If the conversation type is not GAIM_CONV_TYPE_CHAT, this will return @c NULL.
  *
  * @param conv The conversation.